@@ -5,10 +5,10 @@ from abc import ABC
 
 
 class RandomReplayBuffer(ReplayBuffer, ABC):
-    def __init__(self, rp: RandomReplayBufferParams = RandomReplayBufferParams(), *args, **kwargs):
-        if not isinstance(rp, RandomReplayBufferParams):
+    def __init__(self, replay_buffer_params: RandomReplayBufferParams = RandomReplayBufferParams(), *args, **kwargs):
+        if not isinstance(replay_buffer_params, RandomReplayBufferParams):
             raise ValueError("argument rp must be an instance or subclass of RandomReplayBufferParams")
-        super(RandomReplayBuffer, self).__init__(rp, *args, **kwargs)
+        super(RandomReplayBuffer, self).__init__(replay_buffer_params, *args, **kwargs)
 
     def rp_sample(self, limit: int):
         indexes = random.sample(list(range(self.rp_get_length())), limit)
